@@ -233,8 +233,11 @@ void SwitcherBackend::keybdSwitchedToAnotherActivity()
         // create a new Window so the compositor sends us modifier info
         m_inputWindow = new QRasterWindow();
         m_inputWindow->setGeometry(0, 0, 1, 1);
-        m_inputWindow->show();
-        m_inputWindow->update();
+        // Only show once the initial switch has been completed, not cause a switch back
+        connect(&m_activities, &KActivities::Consumer::currentActivityChanged, m_inputWindow, [this] {
+            m_inputWindow->show();
+            m_inputWindow->update();
+        });
         connect(m_inputWindow, &QWindow::activeChanged, this, [this] {
             showActivitySwitcherIfNeeded();
         });
@@ -313,6 +316,11 @@ bool SwitcherBackend::shouldShowSwitcher() const
 
 void SwitcherBackend::setShouldShowSwitcher(bool shouldShowSwitcher)
 {
+    if (m_inputWindow) {
+        delete m_inputWindow;
+        m_inputWindow = nullptr;
+    }
+
     if (m_shouldShowSwitcher == shouldShowSwitcher)
         return;
 
@@ -326,11 +334,6 @@ void SwitcherBackend::setShouldShowSwitcher(bool shouldShowSwitcher)
 
         // We might have an unprocessed onCurrentActivityChanged
         onCurrentActivityChanged(m_activities.currentActivity());
-
-        if (m_inputWindow) {
-            delete m_inputWindow;
-            m_inputWindow = nullptr;
-        }
     }
 
     Q_EMIT shouldShowSwitcherChanged(m_shouldShowSwitcher);
