@@ -64,8 +64,10 @@ void BlacklistedApplicationsModel::load()
     // Loading plugin configuration
     d->pluginConfig->load();
     const auto defaultBlockedValue = d->pluginConfig->defaultBlockedByDefaultValue();
-    auto blockedApplications = QSet<QString>::fromList(d->pluginConfig->blockedApplications());
-    auto allowedApplications = QSet<QString>::fromList(d->pluginConfig->allowedApplications());
+    const auto &blockedAppList = d->pluginConfig->blockedApplications();
+    auto blockedApplications = QSet<QString>(blockedAppList.cbegin(), blockedAppList.cend());
+    const auto &allowedAppList = d->pluginConfig->allowedApplications();
+    auto allowedApplications = QSet<QString>(allowedAppList.cbegin(), allowedAppList.cend());
 
     // Reading new applications from the database
 
@@ -96,14 +98,14 @@ void BlacklistedApplicationsModel::load()
         }
     }
 
-    auto applications = (blockedApplications + allowedApplications).values();
+    QStringList applications = (blockedApplications + allowedApplications).values();
 
     if (applications.length() > 0) {
         std::sort(applications.begin(), applications.end());
 
         beginInsertRows(QModelIndex(), 0, applications.length() - 1);
 
-        foreach (const auto &name, applications) {
+        for (const auto &name : std::as_const(applications)) {
             const auto service = KService::serviceByDesktopName(name);
             const auto blocked = blockedApplications.contains(name);
 
