@@ -15,6 +15,7 @@ class ComponentChooser;
 
 class ComponentChooserData : public KCModuleData
 {
+    Q_OBJECT
 public:
     ComponentChooserData(QObject *parent = nullptr, const QVariantList &args = QVariantList());
 
@@ -29,12 +30,16 @@ public:
     ComponentChooser *fileManagers() const;
     ComponentChooser *terminalEmulators() const;
     ComponentChooser *emailClients() const;
+    ComponentChooser *geoUriHandlers() const;
+    ComponentChooser *telUriHandlers() const;
 
 private:
     ComponentChooser *m_browsers;
     ComponentChooser *m_fileManagers;
     ComponentChooser *m_terminalEmulators;
     ComponentChooser *m_emailClients;
+    ComponentChooser *m_geoUriHandlers;
+    ComponentChooser *m_telUriHandlers;
 };
 
 #endif // COMPONENTCHOOSERDATA_H
