@@ -6,6 +6,8 @@
 
 #include "kcm_componentchooser.h"
 
+#include <QApplication>
+
 #include <KAboutData>
 #include <KBuildSycocaProgressDialog>
 #include <KLocalizedString>
@@ -17,7 +19,7 @@
 #include "componentchooserfilemanager.h"
 #include "componentchooserterminal.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(KcmComponentChooserFactory, "metadata.json", registerPlugin<KcmComponentChooser>(); registerPlugin<ComponentChooserData>();)
+K_PLUGIN_FACTORY_WITH_JSON(KcmComponentChooserFactory, "componentchooser.json", registerPlugin<KcmComponentChooser>(); registerPlugin<ComponentChooserData>();)
 
 KcmComponentChooser::KcmComponentChooser(QObject *parent, const QVariantList &args)
     : KQuickAddons::ManagedConfigModule(parent, args)
@@ -40,6 +42,8 @@ KcmComponentChooser::KcmComponentChooser(QObject *parent, const QVariantList &ar
     connect(fileManagers(), &ComponentChooser::indexChanged, this, &KcmComponentChooser::settingsChanged);
     connect(terminalEmulators(), &ComponentChooser::indexChanged, this, &KcmComponentChooser::settingsChanged);
     connect(emailClients(), &ComponentChooser::indexChanged, this, &KcmComponentChooser::settingsChanged);
+    connect(geoUriHandlers(), &ComponentChooser::indexChanged, this, &KcmComponentChooser::settingsChanged);
+    connect(telUriHandlers(), &ComponentChooser::indexChanged, this, &KcmComponentChooser::settingsChanged);
 }
 
 ComponentChooser *KcmComponentChooser::browsers() const
@@ -62,6 +66,16 @@ ComponentChooser *KcmComponentChooser::fileManagers() const
     return m_data->fileManagers();
 }
 
+ComponentChooser *KcmComponentChooser::geoUriHandlers() const
+{
+    return m_data->geoUriHandlers();
+}
+
+ComponentChooser *KcmComponentChooser::telUriHandlers() const
+{
+    return m_data->telUriHandlers();
+}
+
 void KcmComponentChooser::defaults()
 {
     m_data->defaults();
@@ -75,7 +89,7 @@ void KcmComponentChooser::load()
 void KcmComponentChooser::save()
 {
     m_data->save();
-    KBuildSycocaProgressDialog::rebuildKSycoca(nullptr);
+    KBuildSycocaProgressDialog::rebuildKSycoca(QApplication::activeWindow());
 }
 
 bool KcmComponentChooser::isDefaults() const
