@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2010 Andriy Rysin <rysin@kde.org>
+    SPDX-FileCopyrightText: 2021 Cyril Rossi <cyril.rossi@enioka.com>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +12,8 @@
 #include <KCModule>
 
 class KCMKeyboardWidget;
-class KeyboardConfig;
+class KCMiscKeyboardWidget;
+class KeyboardSettingsData;
 struct Rules;
 
 class KCMKeyboard : public KCModule
@@ -22,15 +24,18 @@ public:
     KCMKeyboard(QWidget *parent, const QVariantList &);
     ~KCMKeyboard() override;
 
+public Q_SLOTS:
     void save() override;
     void load() override;
     void defaults() override;
+    void updateUnmanagedState();
 
 private:
     Rules *rules;
-    KeyboardConfig *keyboardConfig;
+    KeyboardSettingsData *m_data;
     WorkspaceOptions m_workspaceOptions;
     KCMKeyboardWidget *widget;
+    KCMiscKeyboardWidget *m_miscWidget;
 };
 
 #endif /* KCM_KEYBOARD_H_ */
