@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2010 Andriy Rysin <rysin@kde.org>
+    SPDX-FileCopyrightText: 2021 Cyril Rossi <cyril.rossi@enioka.com>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,13 +16,14 @@
 #include <QString>
 #include <QStringList>
 
+#include "keyboardsettings.h"
+
 /**
  * This class provides configuration options for keyboard module
  */
-class KeyboardConfig
+class KeyboardConfig : public KeyboardSettingsBase
 {
 public:
-    static const int MAX_LABEL_LEN = 3;
     static const int NO_LOOPING; // = -1;
 
     enum SwitchingPolicy {
@@ -31,31 +33,30 @@ public:
         SWITCH_POLICY_WINDOW = 3,
     };
 
-    QString keyboardModel;
-    // resetOldXkbOptions is now also "set xkb options"
-    bool resetOldXkbOptions;
-    QStringList xkbOptions;
-
-    // init layouts options
-    bool configureLayouts;
     QList<LayoutUnit> layouts;
-    int layoutLoopCount;
 
-    // switch control options
-    SwitchingPolicy switchingPolicy;
-    //	bool stickySwitching;
-    //	int stickySwitchingDepth;
+    KeyboardConfig(QObject *parent);
 
-    KeyboardConfig();
+    // Getter/setter for switchMode options with SwitchingPolicy enum type values
+    SwitchingPolicy switchingPolicy() const;
+    void setSwitchingPolicy(SwitchingPolicy switchingPolicy);
+    SwitchingPolicy defaultSwitchingPolicyValue() const;
 
+    bool layoutsSaveNeeded() const;
+
+    // Initialize layouts list when activating 'Configure Layouts' option and there is none.
     QList<LayoutUnit> getDefaultLayouts() const;
     QList<LayoutUnit> getExtraLayouts() const;
 
-    void setDefaults();
+    void setDefaults() override;
     void load();
     void save();
 
     static QString getSwitchingPolicyString(SwitchingPolicy switchingPolicy);
+
+private:
+    QList<LayoutUnit> m_referenceLayouts;
+    int m_referenceLayoutLoopCount;
 };
 
 #endif /* KEYBOARD_CONFIG_H_ */
