@@ -7,6 +7,6 @@
 
 #include <KPluginFactory>
 
-K_PLUGIN_FACTORY(MousePluginFactory, registerPlugin<ConfigContainer>();)
+K_PLUGIN_CLASS_WITH_JSON(ConfigContainer, "mouse.json")
 
 #include <plugin.moc>
