@@ -1,22 +1,9 @@
-/**************************************************************************
- * Copyright (C) 2009 Ben Cooksley <ben@eclipse.endoftheinternet.org>     *
- * Copyright (C) 2007 Will Stephenson <wstephenson@kde.org>               *
- *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 2         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program; if not, write to the Free Software            *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA          *
- * 02110-1301, USA.                                                       *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Ben Cooksley <ben@eclipse.endoftheinternet.org>
+    SPDX-FileCopyrightText: 2007 Will Stephenson <wstephenson@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "PredicateModel.h"
 
@@ -149,7 +136,7 @@ void PredicateModel::setRootPredicate(PredicateItem *item)
 
 void PredicateModel::itemUpdated(const QModelIndex &item)
 {
-    emit dataChanged(item, item);
+    Q_EMIT dataChanged(item, item);
 }
 
 void PredicateModel::childrenChanging(const QModelIndex &item, Solid::Predicate::Type oldType)
@@ -162,17 +149,17 @@ void PredicateModel::childrenChanging(const QModelIndex &item, Solid::Predicate:
     }
 
     if (rowCount(item) != 0 && newType != Solid::Predicate::Conjunction && newType != Solid::Predicate::Disjunction) {
-        emit beginRemoveRows(item, 0, 1);
+        beginRemoveRows(item, 0, 1);
         currentItem->updateChildrenStatus();
-        emit endRemoveRows();
+        endRemoveRows();
         return;
     }
 
     bool hasChildren = (newType == Solid::Predicate::Conjunction || newType == Solid::Predicate::Disjunction);
 
     if (rowCount(item) == 0 && hasChildren) {
-        emit beginInsertRows(item, 0, 1);
+        beginInsertRows(item, 0, 1);
         currentItem->updateChildrenStatus();
-        emit endInsertRows();
+        endInsertRows();
     }
 }
