@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2009-2010 Trever Fischer <tdfischer@fedoraproject.org>
     SPDX-FileCopyrightText: 2015 Kai UWe Broulik <kde@privat.broulik.de>
+    SPDX-FileCopyrightText: 2021 Ismael Asensio <isma.af@gmail.com>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,7 +26,8 @@
 #include "DeviceModel.h"
 #include "LayoutSettings.h"
 
-K_PLUGIN_FACTORY(DeviceAutomounterKCMFactory, registerPlugin<DeviceAutomounterKCM>(); registerPlugin<DeviceAutomounterData>();)
+K_PLUGIN_FACTORY_WITH_JSON(DeviceAutomounterKCMFactory, "device_automounter_kcm.json", registerPlugin<DeviceAutomounterKCM>();
+                           registerPlugin<DeviceAutomounterData>();)
 
 DeviceAutomounterKCM::DeviceAutomounterKCM(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args) // DeviceAutomounterKCMFactory::componentData(), parent)
@@ -51,18 +53,14 @@ DeviceAutomounterKCM::DeviceAutomounterKCM(QWidget *parent, const QVariantList &
     deviceView->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
     deviceView->header()->setSectionResizeMode(0, QHeaderView::Stretch);
 
-    connect(kcfg_AutomountOnLogin, &QCheckBox::stateChanged, this, [this](int state) {
-        m_devices->setAutomaticMountOnLogin(state == Qt::Checked);
-    });
-    connect(kcfg_AutomountOnPlugin, &QCheckBox::stateChanged, this, [this](int state) {
-        m_devices->setAutomaticMountOnPlugin(state == Qt::Checked);
+    connect(kcfg_AutomountUnknownDevices, &QCheckBox::stateChanged, this, [this](int state) {
+        m_devices->setAutomaticUnknown(state == Qt::Checked);
     });
 
     connect(deviceView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &DeviceAutomounterKCM::updateForgetDeviceButton);
-
     connect(forgetDevice, &QAbstractButton::clicked, this, &DeviceAutomounterKCM::forgetSelectedDevices);
 
-    forgetDevice->setEnabled(false);
+    connect(m_devices, &QAbstractItemModel::dataChanged, this, &DeviceAutomounterKCM::updateState);
 }
 
 DeviceAutomounterKCM::~DeviceAutomounterKCM()
@@ -70,16 +68,21 @@ DeviceAutomounterKCM::~DeviceAutomounterKCM()
     saveLayout();
 }
 
+void DeviceAutomounterKCM::updateState()
+{
+    kcfg_AutomountUnknownDevices->setEnabled(m_settings->automountOnLogin() || m_settings->automountOnPlugin());
+
+    unmanagedWidgetChangeState(m_unmanagedChanges || m_settings->usrIsSaveNeeded());
+    unmanagedWidgetDefaultState(m_settings->isDefaults());
+}
+
 void DeviceAutomounterKCM::updateForgetDeviceButton()
 {
-    const auto selectedIndex = deviceView->selectionModel()->selectedIndexes();
-    for (const QModelIndex &idx : selectedIndex) {
-        if (idx.data(DeviceModel::TypeRole) == DeviceModel::Detached) {
-            forgetDevice->setEnabled(true);
-            return;
-        }
-    }
-    forgetDevice->setEnabled(false);
+    const auto selectedIndexes = deviceView->selectionModel()->selectedIndexes();
+    const bool isAnyDettached = std::any_of(selectedIndexes.cbegin(), selectedIndexes.cend(), [](const auto &idx) {
+        return idx.data(DeviceModel::TypeRole) == DeviceModel::Detached;
+    });
+    forgetDevice->setEnabled(isAnyDettached);
 }
 
 void DeviceAutomounterKCM::forgetSelectedDevices()
@@ -94,19 +97,21 @@ void DeviceAutomounterKCM::forgetSelectedDevices()
         }
     }
 
-    markAsChanged();
+    m_unmanagedChanges = true;
+    updateState();
 }
 
 void DeviceAutomounterKCM::load()
 {
     KCModule::load();
 
-    kcfg_AutomountUnknownDevices->setEnabled(m_settings->automountEnabled());
-    kcfg_AutomountOnLogin->setEnabled(m_settings->automountEnabled());
-    kcfg_AutomountOnPlugin->setEnabled(m_settings->automountEnabled());
-
     m_devices->reload();
     loadLayout();
+
+    kcfg_AutomountUnknownDevices->setChecked(m_settings->automountUnknownDevices());
+
+    m_unmanagedChanges = false;
+    updateState();
 }
 
 void DeviceAutomounterKCM::save()
@@ -114,37 +119,26 @@ void DeviceAutomounterKCM::save()
     KCModule::save();
     saveLayout();
 
-    const bool enabled = kcfg_AutomountEnabled->isChecked();
-
+    // Housekeeping before saving.
+    // 1. Detect if any of the automount options is set to globally enable automounting
+    // 2. Clean-up removed setting groups
+    bool enabled = m_settings->automountOnLogin() || m_settings->automountOnPlugin();
     QStringList validDevices;
-    for (int i = 0; i < m_devices->rowCount(); ++i) {
-        const QModelIndex &idx = m_devices->index(i, 0);
 
+    for (const QModelIndex &idx : {m_devices->index(DeviceModel::RowAttached, 0), m_devices->index(DeviceModel::RowDetached, 0)}) {
         for (int j = 0; j < m_devices->rowCount(idx); ++j) {
-            QModelIndex dev = m_devices->index(j, 1, idx);
-            const QString device = dev.data(DeviceModel::UdiRole).toString();
-            validDevices << device;
-
-            if (dev.data(Qt::CheckStateRole).toInt() == Qt::Checked) {
-                m_settings->deviceSettings(device).writeEntry("ForceLoginAutomount", true);
-            } else {
-                m_settings->deviceSettings(device).writeEntry("ForceLoginAutomount", false);
-            }
-
-            dev = dev.sibling(j, 2);
-
-            if (dev.data(Qt::CheckStateRole).toInt() == Qt::Checked) {
-                m_settings->deviceSettings(device).writeEntry("ForceAttachAutomount", true);
-            } else {
-                m_settings->deviceSettings(device).writeEntry("ForceAttachAutomount", false);
-            }
+            const QString udi = m_devices->index(j, 0, idx).data(DeviceModel::UdiRole).toString();
+            validDevices << udi;
+            enabled |= m_settings->deviceSettings(udi)->mountOnLogin() | m_settings->deviceSettings(udi)->mountOnAttach();
         }
     }
 
+    m_settings->setAutomountEnabled(enabled);
+
     const auto knownDevices = m_settings->knownDevices();
     for (const QString &possibleDevice : knownDevices) {
         if (!validDevices.contains(possibleDevice)) {
-            m_settings->deviceSettings(possibleDevice).deleteGroup();
+            m_settings->removeDeviceGroup(possibleDevice);
         }
     }
 
@@ -168,6 +162,14 @@ void DeviceAutomounterKCM::save()
     dbus.call(msg, QDBus::NoBlock);
 }
 
+void DeviceAutomounterKCM::defaults()
+{
+    KCModule::defaults();
+
+    m_settings->setDefaults();
+    m_devices->updateCheckedColumns();
+}
+
 void DeviceAutomounterKCM::saveLayout()
 {
     QList<int> widths;
@@ -179,9 +181,8 @@ void DeviceAutomounterKCM::saveLayout()
     }
 
     LayoutSettings::setHeaderWidths(widths);
-    // Check DeviceModel.cpp, thats where the magic row numbers come from.
-    LayoutSettings::setAttachedExpanded(deviceView->isExpanded(m_devices->index(0, 0)));
-    LayoutSettings::setDetachedExpanded(deviceView->isExpanded(m_devices->index(1, 0)));
+    LayoutSettings::setAttachedExpanded(deviceView->isExpanded(m_devices->index(DeviceModel::RowAttached, 0)));
+    LayoutSettings::setDetachedExpanded(deviceView->isExpanded(m_devices->index(DeviceModel::RowDetached, 0)));
     LayoutSettings::self()->save();
 }
 
@@ -200,8 +201,8 @@ void DeviceAutomounterKCM::loadLayout()
         deviceView->setColumnWidth(i, widths[i]);
     }
 
-    deviceView->setExpanded(m_devices->index(0, 0), LayoutSettings::attachedExpanded());
-    deviceView->setExpanded(m_devices->index(1, 0), LayoutSettings::detachedExpanded());
+    deviceView->setExpanded(m_devices->index(DeviceModel::RowAttached, 0), LayoutSettings::attachedExpanded());
+    deviceView->setExpanded(m_devices->index(DeviceModel::RowDetached, 0), LayoutSettings::detachedExpanded());
 }
 
 #include "DeviceAutomounterKCM.moc"
